Potrdila | OiRA
Description: Glede na pristop nacionalnega partnerja/razvijalca orodja OiRA, lahko za svojo oceno morda pridobite potrdilo. Za podrobnosti o prednostih takih potrdil se obrnite na svojega nacionalnega partnerja orodja OiRA.

Teme

# Potrdila

Glede na pristop nacionalnega partnerja/razvijalca orodja OiRA, lahko za svojo oceno morda pridobite potrdilo. Za podrobnosti o prednostih takih potrdil se obrnite na svojega nacionalnega partnerja orodja OiRA.

Kako pridobiti potrdilo?

## Izvedite celovito oceno tveganja.

Med postopkom izdelave ocene tveganja se v orodju OiRA beleži vaš napredek. Ko ocenite več tveganj, vas orodje obvesti o možnosti pridobitve potrdila o zaključku celovite ocene tveganja. Vsak nacionalni partner/razvijalec orodja OiRA določi prag (odstotke) za ,celovito‘ oceno tveganja. Potrdilo je na voljo v oddelku ,Status‘ v meniju na levi strani zaslona.

Na strani s statusom je prikazano, da je na voljo potrdilo.

## Oglejte si svoje potrdilo in ga objavite.

Ko kliknete gumb ,Oglej si potrdilo‘, ste pozvani k vnosu imena podjetja, za katero želite izdati potrdilo. Glede na nacionalne nastavitve boste morda pozvani, da vnesete dodatne podatke in zagotovite, da so v potrdilu vse informacije, ki jih morate zagotoviti.

Vnesite vse informacije, potrebne za potrdilo.

Če označite polje ,Objavi javno‘, se prikaže enolična povezava (URL) do vašega potrdila. Povezavo kopirajte in jo pošljite zadevnim osebam kot dokazilo, da ste izvedli oceno tveganja.

Opomba: Javno se objavijo samo podatki, prikazani na tej strani. Ta povezava ni na voljo v meniju spletnega mesta OiRA, saj je bila določena samo za vas. V teoriji lahko kdor koli, ki brska po internetu, vidi potrdilo, ki ste ga ustvarili.

V potrdilu je navedeno le, da ste v orodju za oceno tveganja odgovorili na izjave o določenem številu tveganj, in ne vključuje nobenih drugih informacij. Posamezne odgovore v oceni tveganja, ki ste jih navedli z uporabo orodja OiRA, si lahko ogledate le vi in nihče drug.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More